@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,10 +15,18 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+""" Assignment tests, cover most forms of them. """
+
 from __future__ import print_function
 
 import sys
 
+# Tests are dirty on purpose.
+#
+# pylint: disable=broad-except,global-variable-undefined,redeclared-assigned-name
+# pylint: disable=global-variable-not-assigned,invalid-name,self-assigning-variable
+
+
 def someFunction():
     a = 2
     print("Simple assignment to variable:", a)
@@ -40,11 +48,11 @@ def someFunction():
     j = [h, i] = (7, 9)
     print("Complex Assignment from variable list:", j, type(j), h, i)
 
-    a, (b,c) = 1, (2,3)
+    a, (b, c) = 1, (2, 3)
     print("Assignment to nested tuples:", a, b, c)
 
     v = [1, 2, 3, 4]
-    v[2:3] = (8,9)
+    v[2:3] = (8, 9)
     print("Assignment to list slice", v)
 
 
@@ -61,12 +69,12 @@ def otherFunction():
 
     a, b, c = Iterable()
 
-    print("Assignments from iterable", a ,b ,c)
+    print("Assignments from iterable", a, b, c)
 
-    print("Assignments from too small iterable",end = ' ')
+    print("Assignments from too small iterable", end=" ")
 
     try:
-        f, g = 1,
+        f, g = (1,)
     except Exception as e:
         print("gave", type(e), repr(e))
 
@@ -80,7 +88,7 @@ def otherFunction():
         except UnboundLocalError:
             print("Variable g is untouched")
 
-    print("Assignments from too large iterable", end = ' ')
+    print("Assignments from too large iterable", end=" ")
 
     try:
         d, j = 1, 2, 3
@@ -101,6 +109,7 @@ def otherFunction():
         def __init__(self, n):
             self.n = n
             self.i = 0
+
         def __next__(self):
             res = self.i
             if res >= self.n:
@@ -109,29 +118,32 @@ def otherFunction():
             return res
 
         if sys.version_info[0] < 3:
+
             def next(self):
                 return self.__next__()
 
     class IteratingSequenceClass:
         def __init__(self, n):
             self.n = n
+
         def __iter__(self):
             return BasicIterClass(self.n)
 
+    print("Exception from iterating over too short class:", end=" ")
     try:
         a, b, c = IteratingSequenceClass(2)
     except ValueError:
-        print("Exception from iterating over too short class", sys.exc_info())
+        print("gave", sys.exc_info())
 
 
 def anotherFunction():
     d = {}
 
-    print("Assignment to dictionary with comma subscript:", end = "")
-    # d[ "f" ] = 3
+    print("Assignment to dictionary with comma subscript:", end="")
+    # d["f"] = 3
 
-    d['a', 'b'] = 6
-    d['c', 'b'] = 9
+    d["a", "b"] = 6
+    d["c", "b"] = 9
 
     print(sorted(d.items()))
 
@@ -145,14 +157,15 @@ def swapVariables():
 
     print(a, b)
 
+
 def interuptedUnpack():
     a = 1
     b = 2
 
-    print("Assignment from a too short tuple to multiple targets:", end = ' ')
+    print("Assignment from a too short tuple to multiple targets:", end=" ")
 
     try:
-        s = a,
+        s = (a,)
 
         c, d = s
     except ValueError as e:
@@ -174,14 +187,15 @@ def interuptedUnpack():
     except AttributeError:
         print("Interrupted unpack, leaves value assigned", a)
 
+
 def multiTargetInterrupt():
     a = 1
     b = 2
 
-    print("Multiple, overlapping targets", end = "")
+    print("Multiple, overlapping targets", end="")
 
-    d = c, d = a, b  # @UnusedVariable
-    print(d, c, end = "")
+    d = c, d = a, b
+    print(d, c, end="")
 
     del c
     del d
@@ -189,7 +203,7 @@ def multiTargetInterrupt():
     c, d = d = a, b
     print(d, c)
 
-    print("Error during multiple assignments", end = "")
+    print("Error during multiple assignments", end="")
 
     del c
     del d
@@ -205,7 +219,7 @@ def multiTargetInterrupt():
     del d
     e = 9
 
-    print("Error during multiple assignments", end = "")
+    print("Error during multiple assignments", end="")
 
     try:
         c, d = z.a, e = a, b
@@ -220,6 +234,7 @@ def optimizeableTargets():
 
     print("Optimizable slice operation, results in", a)
 
+
 def complexDel():
     a = b = c = d = 1
 
@@ -230,6 +245,7 @@ def complexDel():
     except UnboundLocalError as e:
         print("yes, del worked", repr(e))
 
+
 def sliceDel():
     # Python3 ranges are not lists.
     a = list(range(6))
@@ -238,6 +254,7 @@ def sliceDel():
 
     print("Del slice operation, results in", a)
 
+
 def globalErrors():
     global unassigned_1, unassigned_2
 
@@ -246,7 +263,6 @@ def globalErrors():
     except NameError as e:
         print("Accessing unassigned global gives", repr(e))
 
-
     try:
         del unassigned_2
     except NameError as e:
@@ -254,7 +270,7 @@ def globalErrors():
 
 
 someFunction()
-varargsFunction(1,2,3,4)
+varargsFunction(1, 2, 3, 4)
 otherFunction()
 anotherFunction()
 swapVariables()
