@@ -1,4 +1,4 @@
-#     Copyright 2015, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -15,12 +15,17 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
+""" Using absolute import, do from module imports.
+
+"""
+
 from __future__ import absolute_import, print_function
 
 from foobar import util
 
+from . import local  # pylint: disable=unused-import
+
 
 class Foobar(object):
-
     def __init__(self):
-        print(util.foo())
+        print(util.someFunction())
